pub struct Edges;Expand description
Interpret the index buffer as a list of vertex pairs representing edges.
Suitable for edge-based meshes or wireframes, where each pair of indices defines a line segment.
This implementation prunes zero length edges when PruneDegenerate is active
Use with the TopologyPolicy type parameter in dedup, dedup_exact and dedup_exact_from_iter.